@@ -127,6 +127,9 @@ class Sopel(irc.Bot):
         modules. See :class:`sopel.tools.Sopel.SopelMemory`
         """
 
+        self.shutdown_methods = []
+        """List of methods to call on shutdown"""
+
         self.scheduler = sopel.tools.jobs.JobScheduler(self)
         self.scheduler.start()
 
@@ -217,12 +220,14 @@ class Sopel(irc.Bot):
             # TODO this should somehow find the right job to remove, rather than
             # clearing the entire queue. Issue #831
             self.scheduler.clear_jobs()
-        if (getattr(obj, '__name__', None) == 'shutdown'
-                and obj in self.shutdown_methods):
+        if (getattr(obj, '__name__', None) == 'shutdown' and
+                    obj in self.shutdown_methods):
             self.shutdown_methods.remove(obj)
 
-    def register(self, callables, jobs, shutdowns):
-        self.shutdown_methods = shutdowns
+    def register(self, callables, jobs, shutdowns, urls):
+        # Append module's shutdown function to the bot's list of functions to
+        # call on shutdown
+        self.shutdown_methods += shutdowns
         for callbl in callables:
             for rule in callbl.rule:
                 self._callables[callbl.priority][rule].append(callbl)
@@ -239,6 +244,11 @@ class Sopel(irc.Bot):
                 job = sopel.tools.jobs.Job(interval, func)
                 self.scheduler.add_job(job)
 
+        if not self.memory.contains('url_callbacks'):
+            self.memory['url_callbacks'] = tools.SopelMemory()
+        for func in urls:
+            self.memory['url_callbacks'][func.url_regex] = func
+
     def part(self, channel, msg=None):
         """Part a channel."""
         self.write(['PART', channel], msg)
@@ -463,7 +473,7 @@ class Sopel(irc.Bot):
 
         try:
             exit_code = func(sopel, trigger)
-        except Exception:
+        except Exception:  # TODO: Be specific
             exit_code = None
             self.error(trigger)
 
