@@ -12,7 +12,6 @@ dispatch function in bot.py and making it easier to maintain.
 # Licensed under the Eiffel Forum License 2.
 from __future__ import unicode_literals, absolute_import, print_function, division
 
-
 from random import randint
 import re
 import sys
@@ -51,6 +50,14 @@ def auth_after_register(bot):
             account + ' ' + password
         ))
 
+    elif bot.config.core.auth_method == 'Q':
+        account = bot.config.core.auth_username
+        password = bot.config.core.auth_password
+        bot.write((
+            'AUTH',
+            account + ' ' + password
+        ))
+
 
 @sopel.module.event(events.RPL_WELCOME, events.RPL_LUSERCLIENT)
 @sopel.module.rule('.*')
@@ -157,7 +164,7 @@ def handle_names(bot, trigger):
     """Handle NAMES response, happens when joining to channels."""
     names = trigger.split()
 
-    #TODO specific to one channel type. See issue 281.
+    # TODO specific to one channel type. See issue 281.
     channels = re.search('(#\S*)', trigger.raw)
     if not channels:
         return
@@ -357,6 +364,7 @@ def track_join(bot, trigger):
     user = bot.users.get(trigger.nick)
     if user is None:
         user = User(trigger.nick, trigger.user, trigger.host)
+        bot.users[trigger.nick] = user
     bot.channels[trigger.sender].add_user(user)
 
     if len(trigger.args) > 1 and trigger.args[1] != '*' and (
@@ -535,7 +543,7 @@ def sasl_success(bot, trigger):
     bot.write(('CAP', 'END'))
 
 
-#Live blocklist editing
+# Live blocklist editing
 
 
 @sopel.module.commands('blocks')
@@ -696,12 +704,16 @@ def track_notify(bot, trigger):
 
 
 @sopel.module.rule('.*')
+@sopel.module.event('TOPIC')
 @sopel.module.event(events.RPL_TOPIC)
 @sopel.module.priority('high')
 @sopel.module.thread(False)
 @sopel.module.unblockable
 def track_topic(bot, trigger):
-    channel = trigger.args[1]
+    if trigger.event != 'TOPIC':
+        channel = trigger.args[1]
+    else:
+        channel = trigger.args[0]
     if channel not in bot.channels:
         return
     bot.channels[channel].topic = trigger.args[-1]
