@@ -16,8 +16,8 @@ _regex_type = type(re.compile(''))
 
 
 def get_module_description(path):
-    good_file = (os.path.isfile(path) and path.endswith('.py')
-                 and not path.startswith('_'))
+    good_file = (os.path.isfile(path) and
+                 path.endswith('.py') and not path.startswith('_'))
     good_dir = (os.path.isdir(path) and
                 os.path.isfile(os.path.join(path, '__init__.py')))
     if good_file:
@@ -68,7 +68,7 @@ def enumerate_modules(config, show_all=False):
     # TODO does this work with all possible install mechanisms?
     try:
         import sopel_modules
-    except:
+    except Exception:  # TODO: Be specific
         pass
     else:
         for directory in sopel_modules.__path__:
@@ -203,14 +203,14 @@ def load_module(name, path, type_):
 
 
 def is_triggerable(obj):
-    return any(hasattr(obj, attr) for attr in ('rule', 'rule', 'intent',
-                                               'commands'))
+    return any(hasattr(obj, attr) for attr in ('rule', 'intent', 'commands'))
 
 
 def clean_module(module, config):
     callables = []
     shutdowns = []
     jobs = []
+    urls = []
     for obj in itervalues(vars(module)):
         if callable(obj):
             if getattr(obj, '__name__', None) == 'shutdown':
@@ -221,4 +221,6 @@ def clean_module(module, config):
             elif hasattr(obj, 'interval'):
                 clean_callable(obj, config)
                 jobs.append(obj)
-    return callables, jobs, shutdowns
+            elif hasattr(obj, 'url_regex'):
+                urls.append(obj)
+    return callables, jobs, shutdowns, urls
