@@ -23,7 +23,7 @@ class TimeSection(StaticSection):
         serialize=validate_timezone,
         default='UTC'
     )
-    """Default time zone (see http://sopel.chat/tz)"""
+    """Default time zone (see https://sopel.chat/tz)"""
     time_format = ValidatedAttribute(
         'time_format',
         parse=validate_format,
@@ -35,7 +35,7 @@ class TimeSection(StaticSection):
 def configure(config):
     config.define_section('clock', TimeSection)
     config.clock.configure_setting(
-        'tz', 'Preferred time zone (http://sopel.chat/tz)')
+        'tz', 'Preferred time zone (https://sopel.chat/tz)')
     config.clock.configure_setting(
         'time_format', 'Preferred time format (http://strftime.net)')
 
@@ -65,7 +65,7 @@ def f_time(bot, trigger):
 def update_user(bot, trigger):
     """
     Set your preferred time zone. Most timezones will work, but it's best to
-    use one from http://sopel.chat/tz
+    use one from https://sopel.chat/tz
     """
     if not pytz:
         bot.reply("Sorry, I don't have timezone support installed.")
@@ -73,16 +73,16 @@ def update_user(bot, trigger):
         tz = trigger.group(2)
         if not tz:
             bot.reply("What timezone do you want to set? Try one from "
-                      "http://sopel.chat/tz")
+                      "https://sopel.chat/tz")
             return
         if tz not in pytz.all_timezones:
             bot.reply("I don't know that time zone. Try one from "
-                      "http://sopel.chat/tz")
+                      "https://sopel.chat/tz")
             return
 
         bot.db.set_nick_value(trigger.nick, 'timezone', tz)
         if len(tz) < 7:
-            bot.say("Okay, {}, but you should use one from http://sopel.chat/tz "
+            bot.say("Okay, {}, but you should use one from https://sopel.chat/tz "
                     "if you use DST.".format(trigger.nick))
         else:
             bot.reply('I now have you in the %s time zone.' % tz)
@@ -133,7 +133,7 @@ def update_user_format(bot, trigger):
 
     try:
         timef = format_time(db=bot.db, zone=tz, nick=trigger.nick)
-    except:
+    except Exception:  # TODO: Be specific
         bot.reply("That format doesn't work. Try using"
                   " http://strftime.net to make one.")
         # New format doesn't work. Revert save in database.
@@ -179,16 +179,16 @@ def update_channel(bot, trigger):
         tz = trigger.group(2)
         if not tz:
             bot.reply("What timezone do you want to set? Try one from "
-                      "http://sopel.chat/tz")
+                      "https://sopel.chat/tz")
             return
         if tz not in pytz.all_timezones:
             bot.reply("I don't know that time zone. Try one from "
-                      "http://sopel.chat/tz")
+                      "https://sopel.chat/tz")
             return
 
         bot.db.set_channel_value(trigger.sender, 'timezone', tz)
         if len(tz) < 7:
-            bot.say("Okay, {}, but you should use one from http://sopel.chat/tz "
+            bot.say("Okay, {}, but you should use one from https://sopel.chat/tz "
                     "if you use DST.".format(trigger.nick))
         else:
             bot.reply(
@@ -243,7 +243,7 @@ def update_channel_format(bot, trigger):
 
     try:
         timef = format_time(db=bot.db, zone=tz, channel=trigger.sender)
-    except:
+    except Exception:  # TODO: Be specific
         bot.reply("That format doesn't work. Try using"
                   " http://strftime.net to make one.")
         # New format doesn't work. Revert save in database.
