@@ -4,6 +4,7 @@
 # Copyright 2008, Sean B. Palmer, inamidst.com
 # Licensed under the Eiffel Forum License 2.
 from __future__ import unicode_literals, absolute_import, print_function, division
+
 import unicodedata
 import sys
 from sopel.module import commands, example, NOLIMIT
@@ -28,7 +29,7 @@ def codepoint(bot, trigger):
             arg = arg[2:]
         try:
             arg = unichr(int(arg, 16))
-        except:
+        except Exception:  # TODO: Be specific
             bot.reply("That's not a valid code point.")
             return NOLIMIT
 
@@ -47,6 +48,7 @@ def codepoint(bot, trigger):
         template = 'U+%s %s (\xe2\x97\x8c%s)'
     bot.say(template % (point, name, arg))
 
+
 if __name__ == "__main__":
     from sopel.test_tools import run_example_tests
     run_example_tests(__file__)
