@@ -8,13 +8,14 @@
 from __future__ import unicode_literals, absolute_import, print_function, division
 
 import re
-from contextlib import closing
-from sopel import web, tools
+from sopel import web, tools, __version__
 from sopel.module import commands, rule, example
 from sopel.config.types import ValidatedAttribute, ListAttribute, StaticSection
 
 import requests
 
+USER_AGENT = 'Sopel/{} (https://sopel.chat)'.format(__version__)
+default_headers = {'User-Agent': USER_AGENT}
 url_finder = None
 # These are used to clean up the title tag before actually parsing it. Not the
 # world's best way to do this, but it'll do for now.
@@ -47,12 +48,9 @@ def configure(config):
     )
 
 
-def setup(bot=None):
+def setup(bot):
     global url_finder
 
-    # TODO figure out why this is needed, and get rid of it, because really?
-    if not bot:
-        return
     bot.config.define_section('url', UrlSection)
 
     if bot.config.url.exclude:
@@ -151,7 +149,7 @@ def process_urls(bot, trigger, urls):
             # Magic stuff to account for international domain names
             try:
                 url = web.iri_to_uri(url)
-            except:
+            except Exception:  # TODO: Be specific
                 pass
             # First, check that the URL we got doesn't match
             matched = check_callbacks(bot, trigger, url, False)
@@ -176,7 +174,8 @@ def check_callbacks(bot, trigger, url, run=True):
     for regex, function in tools.iteritems(bot.memory['url_callbacks']):
         match = regex.search(url)
         if match:
-            if run:
+            # Always run ones from @url; they don't run on their own.
+            if run or hasattr(function, 'url_regex'):
                 function(bot, trigger, match)
             matched = True
     return matched
@@ -184,29 +183,28 @@ def check_callbacks(bot, trigger, url, run=True):
 
 def find_title(url, verify=True):
     """Return the title for the given URL."""
-    response = requests.get(url, stream=True, verify=verify)
     try:
-        content = ''
-        for byte in response.iter_content(chunk_size=512, decode_unicode=True):
-            if not isinstance(byte, bytes):
-                content += byte
-            else:
+        response = requests.get(url, stream=True, verify=verify,
+                                headers=default_headers)
+        content = b''
+        for byte in response.iter_content(chunk_size=512):
+            content += byte
+            if b'</title>' in content or len(content) > max_bytes:
                 break
-            if '</title>' in content or len(content) > max_bytes:
-                break
-    except UnicodeDecodeError:
-        return  # Fail silently when data can't be decoded
-    finally:
-        # need to close the connexion because we have not read all the data
+        content = content.decode('utf-8', errors='ignore')
+        # Need to close the connection because we have not read all
+        # the data
         response.close()
+    except requests.exceptions.ConnectionError:
+        return None
 
     # Some cleanup that I don't really grok, but was in the original, so
     # we'll keep it (with the compiled regexes made global) for now.
     content = title_tag_data.sub(r'<\1title>', content)
     content = quoted_title.sub('', content)
 
-    start = content.find('<title>')
-    end = content.find('</title>')
+    start = content.rfind('<title>')
+    end = content.rfind('</title>')
     if start == -1 or end == -1:
         return
     title = web.decode(content[start + 7:end])
@@ -232,6 +230,7 @@ def get_hostname(url):
         hostname = hostname[:slash]
     return hostname
 
+
 if __name__ == "__main__":
     from sopel.test_tools import run_example_tests
     run_example_tests(__file__)
