@@ -17,7 +17,6 @@ from __future__ import unicode_literals, absolute_import, print_function, divisi
 import re
 import sys
 import urllib
-import os.path
 import requests
 
 from sopel import __version__
@@ -47,7 +46,7 @@ try:
 except ImportError:
     has_ssl = False
 
-USER_AGENT = 'Sopel/{} (http://sopel.chat)'.format(__version__)
+USER_AGENT = 'Sopel/{} (https://sopel.chat)'.format(__version__)
 default_headers = {'User-Agent': USER_AGENT}
 ca_certs = None  # Will be overriden when config loads. This is for an edge case.
 
@@ -87,7 +86,8 @@ def get(uri, timeout=20, headers=None, return_headers=False,
         headers = default_headers
     else:
         tmp = default_headers.copy()
-        headers = tmp.update(headers)
+        tmp.update(headers)
+        headers = tmp
     u = requests.get(uri, timeout=timeout, headers=headers, verify=verify_ssl)
     bytes = u.content
     u.close()
@@ -117,7 +117,8 @@ def head(uri, timeout=20, headers=None, verify_ssl=True):
         headers = default_headers
     else:
         tmp = default_headers.copy()
-        headers = tmp.update(headers)
+        tmp.update(headers)
+        headers = tmp
     u = requests.get(uri, timeout=timeout, headers=headers, verify=verify_ssl)
     info = u.headers
     u.close()
@@ -129,8 +130,9 @@ def head(uri, timeout=20, headers=None, verify_ssl=True):
 def post(uri, query, limit_bytes=None, timeout=20, verify_ssl=True, return_headers=False):
     """Execute an HTTP POST query. Deprecated.
 
-    `uri` is the target URI, and `query` is the POST data. `headers` is a dict
-    of HTTP headers to send with the request.
+    `uri` is the target URI, and `query` is the POST data.
+
+    If `return_headers` is true, returns a tuple of (bytes, headers).
 
     `limit_bytes` is ignored.
 
@@ -147,6 +149,7 @@ def post(uri, query, limit_bytes=None, timeout=20, verify_ssl=True, return_heade
         headers['_http_status'] = u.status_code
         return (bytes, headers)
 
+
 r_entity = re.compile(r'&([^;\s]+);')
 
 
@@ -178,7 +181,8 @@ def get_urllib_object(uri, timeout, headers=None, verify_ssl=True, data=None):
         headers = default_headers
     else:
         tmp = default_headers.copy()
-        headers = tmp.update(headers)
+        tmp.update(headers)
+        headers = tmp
     if data is not None:
         response = requests.post(uri, timeout=timeout, verify=verify_ssl,
                                  data=data, headers=headers)
